@@ -1,4 +1,4 @@
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 
 import logging
 
@@ -8,4 +8,5 @@ logging.getLogger(__name__).propagate = False
 from .core.depends_contoroller import get_depends  # noqa
 from .core.machina import Event, Machina  # noqa
 from .core.params_function import Depends  # noqa
-from .core.retry import Retry, RetryExponentialAndJitter, RetryFibonacci, RetryFixed, RetryRange, RetryRule  # noqa
+from .lib.retry import Retry, RetryExponentialAndJitter, RetryFibonacci, RetryFixed, RetryRange, RetryRule  # noqa
+from .lib.time_semaphore import TimeSemaphore  # noqa
